pub struct StatsCollector { /* private fields */ }Expand description
StatCollector is responsible for aggregating statistics as the filesystem is traversed, as well as parsing a DirEntry’s file type
Implementations
Sourceimpl StatsCollector
impl StatsCollector
pub fn new() -> StatsCollector